package com.bonus.canteen.core.supermarket.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.supermarket.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.supermarket.domain.SupermarketProduct;
import com.bonus.canteen.core.supermarket.service.ISupermarketProductService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 超市商城商品Controller
 * 
 * @author xsheng
 * @date 2025-06-03
 */
@Api(tags = "超市商城商品接口")
@RestController
@RequestMapping("/supermarket_product")
public class SupermarketProductController extends BaseController {
    @Autowired
    private ISupermarketProductService supermarketProductService;

    /**
     * 查询超市商城商品列表
     */
    @ApiOperation(value = "查询超市商城商品列表")
    //@RequiresPermissions("supermarket:product:list")
    @GetMapping("/list")
    public TableDataInfo list(SupermarketProduct supermarketProduct) {
        startPage();
        List<SupermarketProduct> list = supermarketProductService.selectSupermarketProductList(supermarketProduct);
        return getDataTable(list);
    }

    /**
     * 导出超市商城商品列表
     */
    @ApiOperation(value = "导出超市商城商品列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:product:export")
    @SysLog(title = "超市商城商品", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出超市商城商品")
    @PostMapping("/export")
    public void export(HttpServletResponse response, SupermarketProduct supermarketProduct) {
        List<SupermarketProduct> list = supermarketProductService.selectSupermarketProductList(supermarketProduct);
        ExcelUtil<SupermarketProduct> util = new ExcelUtil<SupermarketProduct>(SupermarketProduct.class);
        util.exportExcel(response, list, "超市商城商品数据");
    }

    /**
     * 获取超市商城商品详细信息
     */
    @ApiOperation(value = "获取超市商城商品详细信息")
    //@RequiresPermissions("supermarket:product:query")
    @GetMapping(value = "/{productId}")
    public AjaxResult getInfo(@PathVariable("productId") Long productId) {
        return success(supermarketProductService.selectSupermarketProductByProductId(productId));
    }

    /**
     * 新增超市商城商品
     */
    @ApiOperation(value = "新增超市商城商品")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:product:add")
    @SysLog(title = "超市商城商品", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增超市商城商品")
    @PostMapping
    public AjaxResult add(@RequestBody SupermarketProduct supermarketProduct) {
        try {
            return toAjax(supermarketProductService.insertSupermarketProduct(supermarketProduct));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改超市商城商品
     */
    @ApiOperation(value = "修改超市商城商品")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:product:edit")
    @SysLog(title = "超市商城商品", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改超市商城商品")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody SupermarketProduct supermarketProduct) {
        try {
            return toAjax(supermarketProductService.updateSupermarketProduct(supermarketProduct));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除超市商城商品
     */
    @ApiOperation(value = "删除超市商城商品")
    //@PreventRepeatSubmit
    //@RequiresPermissions("supermarket:product:remove")
    @SysLog(title = "超市商城商品", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除超市商城商品")
	@PostMapping("/del/{productIds}")
    public AjaxResult remove(@PathVariable Long[] productIds) {
        return toAjax(supermarketProductService.deleteSupermarketProductByProductIds(productIds));
    }
}
